@@ -37,7 +37,7 @@ gboolean     g_conf_is_initialized  (void);
 typedef void (*GConfNotifyFunc)(GConfEngine* conf, guint cnxn_id, const gchar* key, GConfValue* value, gpointer user_data);
   
 /* Returns ID of the notification */
-/* returns 0 on error */
+/* returns 0 on error, 0 is an invalid ID */
 guint        g_conf_notify_add(GConfEngine* conf,
                                const gchar* namespace_section, /* dir or key to listen to */
                                GConfNotifyFunc func,
@@ -51,10 +51,10 @@ void         g_conf_notify_remove  (GConfEngine* conf,
 /* Low-level interfaces */
 GConfValue*  g_conf_get            (GConfEngine* conf, const gchar* key, GConfError** err);
 
-void         g_conf_set            (GConfEngine* conf, const gchar* key,
-                                    GConfValue* value, GConfError** err);
+gboolean     g_conf_set            (GConfEngine* conf, const gchar* key,
+                                        GConfValue* value, GConfError** err);
 
-void         g_conf_unset          (GConfEngine* conf, const gchar* key, GConfError** err);
+gboolean     g_conf_unset          (GConfEngine* conf, const gchar* key, GConfError** err);
 
 GSList*      g_conf_all_entries    (GConfEngine* conf, const gchar* dir, GConfError** err);
 
